package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcWpyrwwcl;
import org.apache.ibatis.annotations.Param;

/**
 * 网评员任务完成率（网评系统）Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface TcWpyrwwclMapper 
{
    /**
     * 查询网评员任务完成率（网评系统）
     * 
     * @param id 网评员任务完成率（网评系统）主键
     * @return 网评员任务完成率（网评系统）
     */
    public TcWpyrwwcl selectTcWpyrwwclById(Long id);

    /**
     * 查询网评员任务完成率（网评系统）列表
     * 
     * @param tcWpyrwwcl 网评员任务完成率（网评系统）
     * @return 网评员任务完成率（网评系统）集合
     */
    public List<TcWpyrwwcl> selectTcWpyrwwclList(TcWpyrwwcl tcWpyrwwcl);

    /**
     * 新增网评员任务完成率（网评系统）
     * 
     * @param tcWpyrwwcl 网评员任务完成率（网评系统）
     * @return 结果
     */
    public int insertTcWpyrwwcl(TcWpyrwwcl tcWpyrwwcl);

    /**
     * 修改网评员任务完成率（网评系统）
     * 
     * @param tcWpyrwwcl 网评员任务完成率（网评系统）
     * @return 结果
     */
    public int updateTcWpyrwwcl(TcWpyrwwcl tcWpyrwwcl);

    /**
     * 删除网评员任务完成率（网评系统）
     * 
     * @param id 网评员任务完成率（网评系统）主键
     * @return 结果
     */
    public int deleteTcWpyrwwclById(Long id);

    /**
     * 批量删除网评员任务完成率（网评系统）
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcWpyrwwclByIds(Long[] ids);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
