package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcWpy;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcWpyrwwcl;
import com.ruoyi.tcZz.service.ITcWpyrwwclService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 网评员任务完成率（网评系统）Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "网评员任务完成率")
@RequestMapping("/tcZz/networkEcology/wpyrwwcl")
public class TcWpyrwwclController extends BaseController {
    @Autowired
    private ITcWpyrwwclService tcWpyrwwclService;

    /**
     * 查询网评员任务完成率（网评系统）列表
     */
    @ApiOperation(value = "查询网评员任务完成率（网评系统）列表", response = TcWpyrwwcl.class)
    @GetMapping("/list")
    public TableDataInfo list(TcWpyrwwcl tcWpyrwwcl) {
        startPage();
        List<TcWpyrwwcl> list = tcWpyrwwclService.selectTcWpyrwwclList(tcWpyrwwcl);
        return getDataTable(list);
    }

    /**
     * 导出网评员任务完成率（网评系统）列表
     */
    @ApiOperation(value = "导出网评员任务完成率（网评系统）列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcWpyrwwcl tcWpyrwwcl) {
        List<TcWpyrwwcl> list = tcWpyrwwclService.selectTcWpyrwwclList(tcWpyrwwcl);
        ExcelUtil<TcWpyrwwcl> util = new ExcelUtil<TcWpyrwwcl>(TcWpyrwwcl.class);
        util.exportExcel(response, list, "网评员任务完成率（网评系统）数据");
    }

    /**
     * 获取网评员任务完成率（网评系统）详细信息
     */
    @ApiOperation(value = "获取网评员任务完成率（网评系统）详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcWpyrwwclService.selectTcWpyrwwclById(id));
    }

    /**
     * 新增网评员任务完成率（网评系统）
     */
    @ApiOperation(value = "新增网评员任务完成率")
    @PostMapping
    public AjaxResult add(@RequestBody TcWpyrwwcl tcWpyrwwcl) {
        return toAjax(tcWpyrwwclService.insertTcWpyrwwcl(tcWpyrwwcl));
    }

    /**
     * 修改网评员任务完成率（网评系统）
     */
    @ApiOperation(value = "修改网评员任务完成率")
    @PutMapping
    public AjaxResult edit(@RequestBody TcWpyrwwcl tcWpyrwwcl) {
        return toAjax(tcWpyrwwclService.updateTcWpyrwwcl(tcWpyrwwcl));
    }

    /**
     * 删除网评员任务完成率（网评系统）
     */
    @ApiOperation(value = "删除网评员任务完成率（网评系统）")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcWpyrwwclService.deleteTcWpyrwwclByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcWpyrwwcl> util = new ExcelUtil<TcWpyrwwcl>(TcWpyrwwcl.class);
        List<TcWpyrwwcl> tTcWpyrwwclList = util.importExcel(file.getInputStream());
        tcWpyrwwclService.importUser(tTcWpyrwwclList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcWpyrwwclService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcWpyrwwcl> util = new ExcelUtil<TcWpyrwwcl>(TcWpyrwwcl.class);
        util.importTemplateExcel(response, " 网评员任务完成率（网评系统）");
    }
}
